@@ -108,18 +108,29 @@ void MediaObject::play()
         m_player->resume();
         break;
     default:
-#ifdef __GNUC__
-#warning if we got rid of playinternal, we coulde simply call play and it would resume/play
-#endif
-        playInternal();
+        setupMedia();
+        if (m_player->play())
+            error() << "libVLC:" << LibVLC::errorMessage();
         break;
     }
 }
 
 void MediaObject::pause()
 {
-    if (state() != Phonon::PausedState)
+    DEBUG_BLOCK;
+    switch (m_state) {
+    case BufferingState:
+    case PlayingState:
         m_player->pause();
+        break;
+    case PausedState:
+        return;
+    default:
+        debug() << "doing paused play";
+        setupMedia();
+        m_player->pausedPlay();
+        break;
+    }
 }
 
 void MediaObject::stop()
@@ -179,7 +190,8 @@ void MediaObject::timeChanged(qint64 time)
                 emit prefinishMarkReached(totalTime - time);
             }
         }
-        if (totalTime > -1 && time >= totalTime - ABOUT_TO_FINISH_TIME)
+        // Note that when the totalTime is <= 0 we cannot calculate any sane delta.
+        if (totalTime > 0 && time >= totalTime - ABOUT_TO_FINISH_TIME)
             emitAboutToFinish();
     }
 }
@@ -389,6 +401,7 @@ void MediaObject::setSource(const MediaSource &source)
         break;
     }
 
+    debug() << "Sending currentSourceChanged";
     emit currentSourceChanged(m_mediaSource);
 }
 
@@ -467,6 +480,7 @@ void MediaObject::changeState(Phonon::State newState)
 
 void MediaObject::moveToNextSource()
 {
+    DEBUG_BLOCK;
     if (m_nextSource.type() == MediaSource::Invalid) {
         // No item is scheduled to be next...
         return;
@@ -479,6 +493,7 @@ void MediaObject::moveToNextSource()
 
 inline bool MediaObject::checkGaplessWaiting()
 {
+    DEBUG_BLOCK;
     return m_nextSource.type() != MediaSource::Invalid && m_nextSource.type() != MediaSource::Empty;
 }
 
@@ -491,7 +506,7 @@ inline void MediaObject::unloadMedia()
     }
 }
 
-void MediaObject::playInternal()
+void MediaObject::setupMedia()
 {
     DEBUG_BLOCK;
 
@@ -538,8 +553,6 @@ void MediaObject::playInternal()
 
     // Play
     m_player->setMedia(m_media);
-    if (m_player->play())
-        error() << "libVLC:" << LibVLC::errorMessage();
 }
 
 QString MediaObject::errorString() const
